@@ -17,6 +17,16 @@ class IntegerValue(NamedTuple):
     type: Literal['integer']
     format: str = ''
     example: Optional[int] = None
+    default: Optional[int] = None
+    minimum: Optional[int] = None
+    maximum: Optional[int] = None
+
+
+class FloatValue(NamedTuple):
+    type: Literal['number']
+    format: str = ''
+    example: Optional[float] = None
+    default: Optional[float] = None
 
 
 class StringValue(NamedTuple):
@@ -24,20 +34,25 @@ class StringValue(NamedTuple):
     format: str = ''
     description: str = ''
     enum: PVector[str] = pvector()
+    default: Optional[str] = None
     example: str = ''
 
 
 class BooleanValue(NamedTuple):
     type: Literal['boolean']
+    default: Optional[bool] = None
 
 
 class Reference(NamedTuple):
     ref: Ref
 
 
+RecursiveAttrs = Mapping[str, 'SchemaValue']  # type: ignore
+
+
 class ObjectValue(NamedTuple):
     type: Literal['object']
-    properties: Mapping[str, 'SchemaValue']  # type: ignore
+    properties: RecursiveAttrs
     xml: Mapping[str, Any] = pmap()
 
 
@@ -53,6 +68,7 @@ class ArrayValue(NamedTuple):
 
 SchemaValue = Union[StringValue,       # type: ignore
                     IntegerValue,
+                    FloatValue,
                     BooleanValue,
                     Reference,
                     ObjectValue,
@@ -62,13 +78,13 @@ SchemaValue = Union[StringValue,       # type: ignore
 
 class ObjectSchema(NamedTuple):
     type: Literal['object']
-    properties: Mapping[str, SchemaValue]
+    properties: RecursiveAttrs
     required: FrozenSet[str] = frozenset()
     description: str = ''
 
 
 class InlinedObjectSchema(NamedTuple):
-    properties: Mapping[str, SchemaValue]
+    properties: RecursiveAttrs
     required: FrozenSet[str]
     description: str = ''
 
